Queuetopia.Performer behaviour (queuetopia v2.7.1)
View SourceThe behaviour for a Queuetopia performer.
Summary
Callbacks
Callback invoked by the Queuetopia to perfom a job. It may return :ok, an :ok tuple or a tuple error, with a string as error. Note that any failure in the processing will cause the job to be retried.
Callbacks
@callback backoff(job :: Queuetopia.Queue.Job.t()) :: pos_integer()
@callback handle_failed_job!(Queuetopia.Queue.Job.t()) :: :ok
Callback invoked by the Queuetopia to perfom a job. It may return :ok, an :ok tuple or a tuple error, with a string as error. Note that any failure in the processing will cause the job to be retried.